@@ -28,6 +28,8 @@ def test_ci_runner(host, tmpdir):
     mkdir testproject
     cd testproject
     git init
+    git config user.email "you@example.com"
+    git config user.name "Your Name"
     (
      echo 'jobs:'
      echo '  script: env > /srv/OPENSTACK.out 2>&1 ; \
